@@ -1,8 +1,9 @@
 # -*- coding: utf-8 -*-
 # @Author  : ydf
-# @Time    : 2019/8/8 0008 13:32
+# @Time    : 2022/8/8 0008 13:32
 import json
 # import time
+import time
 
 from funboost.consumers.base_consumer import AbstractConsumer
 from funboost.utils import RedisMixin
@@ -16,13 +17,16 @@ class RedisConsumer(AbstractConsumer, RedisMixin):
     这个是复杂版，一次性拉取100个，简单版在 funboost/consumers/redis_consumer_simple.py
     """
     BROKER_KIND = 2
+    BROKER_EXCLUSIVE_CONFIG_KEYS = ['redis_bulk_push', 'redis_host' ]
+
+    def __init__(self, *args, **kwargs):
+        super().__init__(*args, **kwargs)
+        self.redis_host = self.broker_exclusive_config.get("redis_host")
 
     # noinspection DuplicatedCode
     def _shedual_task000(self):
         while True:
-            result = self.redis_db_frame.blpop(self._queue_name, timeout=60)
-            if result:
-                # self.logger.debug(f'从redis的 [{self._queue_name}] 队列中 取出的消息是：  {result[1].decode()}  ')
+            if result := self.redis_db_frame.blpop(self._queue_name, timeout=60):
                 self._print_message_get_from_broker('reids', result[1].decode())
                 task_dict = json.loads(result[1])
                 kw = {'body': task_dict}
