@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 # @Author  : ydf
-# @Time    : 2019/8/8 0008 13:32
+# @Time    : 2022/8/8 0008 13:32
 """
 
 这个是加强版的可确认消费的redis消费实现，所以比redis_conusmer实现复杂很多。
@@ -30,7 +30,11 @@ class RedisConsumerAckAble(ConsumerConfirmMixinWithTheHelpOfRedisByHearbeat, Abs
     # print(script_4(keys=["text_pipelien1","text_pipelien1b"]))
     """
     BROKER_KIND = 9
+    BROKER_EXCLUSIVE_CONFIG_KEYS = ['redis_host']
 
+    def __init__(self, *args, **kwargs):
+        super().__init__(*args, **kwargs)
+        self.redis_host = self.broker_exclusive_config.get("redis_host")
     def _shedual_task000(self):
         # 可以采用lua脚本，也可以采用redis的watch配合pipeline使用。比代码分两行pop和zadd比还能减少一次io交互，还能防止丢失小概率一个任务。
         lua = '''
