@@ -1,6 +1,6 @@
 ﻿# -*- coding: utf-8 -*-
 # @Author  : ydf
-# @Time    : 2019/8/8 0008 13:32
+# @Time    : 2022/8/8 0008 13:32
 import json
 from funboost.consumers.base_consumer import AbstractConsumer
 from funboost.utils import RedisMixin
@@ -11,12 +11,16 @@ class RedisConsumer(AbstractConsumer, RedisMixin):
     redis作为中间件实现的。
     """
     BROKER_KIND = 2
+    BROKER_EXCLUSIVE_CONFIG_KEYS = ['redis_host']
 
+    def __init__(self, *args, **kwargs):
+        super().__init__(*args, **kwargs)
+        self.redis_host = self.broker_exclusive_config.get("redis_host")
     def _shedual_task(self):
         while True:
             result = self.redis_db_frame.blpop(self._queue_name,timeout=60)
             if result:
-                self.logger.debug(f'从redis的 [{self._queue_name}] 队列中 取出的消息是：  {result[1].decode()}  ')
+                self._print_message_get_from_broker('redis',result[1].decode())
                 task_dict = json.loads(result[1])
                 kw = {'body': task_dict}
                 self._submit_task(kw)
